0.3 (unreleased)
================

New Features
------------

- Added DOI badge to the README file.
- Integrate new SpecViz (#484)

Bug Fixes
---------

- Removed popup when closing CubeViz (#483)
- Fix bug in loading when EXTNAME does not exist (#486)

0.2.1 (2018-11-28)
==================

Current release, place holder.
